@@ -9,6 +9,9 @@ def create_expense(expense):
   authenticate()
   post_url = f"{BASE_URL}"
   result = post(post_url, HEADERS, json.dumps(expense))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = post(post_url, HEADERS, json.dumps(expense))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to create expense. Result: {result}")
   return result
@@ -18,6 +21,9 @@ def update_expense(expense_id, expense):
   authenticate()
   post_url = f"{BASE_URL}/{expense_id}"
   result = put(post_url, HEADERS, json.dumps(expense))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = put(post_url, HEADERS, json.dumps(expense))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update expense. Result: {result}")
   return result
@@ -27,6 +33,9 @@ def get_expense(expense_id):
   authenticate()
   post_url = f"{BASE_URL}/{expense_id}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve expense. Result: {result}")
   return result
@@ -81,6 +90,9 @@ def search_expenses(description=None,
   for name, value in kwargs.items():
     post_url = f"{post_url}&{name}={value}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve expenses. Result: {result}")
   return result
